==> open-xchange-core_7.6.0.orig.tar.bz2: open-xchange-core-7.6.0/com.openexchange.calendar/src/com/openexchange/calendar/itip/ITipAnalysis.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.calendar.itip;

import java.util.ArrayList;
import java.util.EnumSet;
import java.util.List;
import java.util.Set;
import com.openexchange.data.conversion.ical.itip.ITipMessage;


/**
 * {@link ITipAnalysis}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class ITipAnalysis {
    private final List<ITipChange> changes = new ArrayList<ITipChange>();
    private final List<ITipAnnotation> annotations = new ArrayList<ITipAnnotation>();
    private final Set<ITipAction> actions = EnumSet.noneOf(ITipAction.class);
    private ITipMessage message = null;
	private String uid;

    public ITipMessage getMessage() {
        return message;
    }

    public void setMessage(ITipMessage message) {
        this.message = message;
    }

    public List<ITipChange> getChanges() {
        return changes;
    }

    public void addChange(ITipChange change) {
        changes.add(change);
    }

    public List<ITipAnnotation> getAnnotations() {
        return annotations;
    }

    public void addAnnotation(ITipAnnotation annotation) {
        annotations.add(annotation);
    }

    public Set<ITipAction> getActions() {
        return actions;
    }

    public void recommendAction(ITipAction action) {
        actions.add(action);
    }

    public void recommendActions(ITipAction...actions) {
        for (ITipAction action : actions) {
            this.actions.add(action);
        }
    }

    public void setUid(String uid) {
		this.uid = uid;
	}

	public String getUid() {
		return uid;
	}

}

==> open-xchange-core_7.8.1.orig.tar.bz2: open-xchange-core-7.8.1/com.openexchange.calendar/src/com/openexchange/calendar/itip/ITipAnalysis.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.calendar.itip;

import java.util.ArrayList;
import java.util.EnumSet;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import com.openexchange.data.conversion.ical.itip.ITipMessage;


/**
 * {@link ITipAnalysis}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class ITipAnalysis {
    private final List<ITipChange> changes = new ArrayList<ITipChange>();
    private final List<ITipAnnotation> annotations = new ArrayList<ITipAnnotation>();
    private final Set<ITipAction> actions = EnumSet.noneOf(ITipAction.class);
    private ITipMessage message = null;
	private String uid;
	private Map<String, Object> attributes = new HashMap<String, Object>();

    public ITipMessage getMessage() {
        return message;
    }

    public void setMessage(ITipMessage message) {
        this.message = message;
    }

    public List<ITipChange> getChanges() {
        return changes;
    }

    public void addChange(ITipChange change) {
        changes.add(change);
    }

    public List<ITipAnnotation> getAnnotations() {
        return annotations;
    }

    public void addAnnotation(ITipAnnotation annotation) {
        annotations.add(annotation);
    }

    public Set<ITipAction> getActions() {
        return actions;
    }

    public void recommendAction(ITipAction action) {
        actions.add(action);
    }

    public void recommendActions(ITipAction...actions) {
        for (ITipAction action : actions) {
            this.actions.add(action);
        }
    }

    public void setUid(String uid) {
		this.uid = uid;
	}

	public String getUid() {
		return uid;
	}

    public Map<String, Object> getAttributes() {
        return attributes;
    }

    public void setAttributes(Map<String, Object> attributes) {
        this.attributes = attributes;
    }

}
